==> cbang_0.0.0.tar.gz: cbang-1.3.2/src/cbang/debug/StackTrace.cpp <==
/******************************************************************************\

          This file is part of the C! library.  A.K.A the cbang library.

                Copyright (c) 2003-2019, Cauldron Development LLC
                   Copyright (c) 2003-2017, Stanford University
                               All rights reserved.

         The C! library is free software: you can redistribute it and/or
        modify it under the terms of the GNU Lesser General Public License
       as published by the Free Software Foundation, either version 2.1 of
               the License, or (at your option) any later version.

        The C! library is distributed in the hope that it will be useful,
          but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
                 Lesser General Public License for more details.

         You should have received a copy of the GNU Lesser General Public
                 License along with the C! library.  If not, see
                         <http://www.gnu.org/licenses/>.

        In addition, BSD licensing may be granted on a case by case basis
        by written permission from at least one of the copyright holders.
           You may request written permission by emailing the authors.

                  For information regarding this software email:
                                 Joseph Coffland
                          joseph@cauldrondevelopment.com

\******************************************************************************/

#include "StackTrace.h"
#include "Debugger.h"

#include <iostream>

using namespace cb;
using namespace std;


ostream &StackTrace::print(ostream &stream) const {
  unsigned count = 0;
  const_iterator it;
  for (it = begin(); it != end(); it++)
    stream << '#' << count++ << ' ' << *it << endl;

  return stream;
}


StackTrace StackTrace::get() {return Debugger::getStackTrace();}

==> cbang-1.6.0.tar.gz: cbang-1.6.0/src/cbang/debug/StackTrace.cpp <==
/******************************************************************************\

          This file is part of the C! library.  A.K.A the cbang library.

                Copyright (c) 2003-2019, Cauldron Development LLC
                   Copyright (c) 2003-2017, Stanford University
                               All rights reserved.

         The C! library is free software: you can redistribute it and/or
        modify it under the terms of the GNU Lesser General Public License
       as published by the Free Software Foundation, either version 2.1 of
               the License, or (at your option) any later version.

        The C! library is distributed in the hope that it will be useful,
          but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
                 Lesser General Public License for more details.

         You should have received a copy of the GNU Lesser General Public
                 License along with the C! library.  If not, see
                         <http://www.gnu.org/licenses/>.

        In addition, BSD licensing may be granted on a case by case basis
        by written permission from at least one of the copyright holders.
           You may request written permission by emailing the authors.

                  For information regarding this software email:
                                 Joseph Coffland
                          joseph@cauldrondevelopment.com

\******************************************************************************/

#include "StackTrace.h"
#include "Debugger.h"

#include <cbang/json/Sink.h>

#include <iostream>

using namespace cb;
using namespace std;


StackTrace StackTrace::get() {return Debugger::getStackTrace();}


ostream &StackTrace::print(ostream &stream) const {
  unsigned count = 0;

  for (auto it = begin(); it != end(); it++)
    stream << '#' << count++ << ' ' << *it << endl;

  return stream;
}


void StackTrace::write(JSON::Sink &sink) const {
  sink.beginList();

  for (auto it = begin(); it != end(); it++) {
    sink.beginAppend();
    it->write(sink);
  }

  sink.endList();
}
